==> package-search-223.7571.182-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/models/operations/PackageSearchOperation.kt <==
/*******************************************************************************
 * Copyright 2000-2022 JetBrains s.r.o. and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.operations

import com.intellij.buildsystem.model.unified.UnifiedDependency
import com.intellij.buildsystem.model.unified.UnifiedDependencyRepository
import com.jetbrains.packagesearch.intellij.plugin.extensibility.ProjectModule
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageScope
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageVersion

internal sealed class PackageSearchOperation<T> {

    abstract val model: T
    abstract val projectModule: ProjectModule

    sealed class Package : PackageSearchOperation<UnifiedDependency>() {

        abstract override val model: UnifiedDependency

        data class Install(
            override val model: UnifiedDependency,
            override val projectModule: ProjectModule,
            val newVersion: PackageVersion,
            val newScope: PackageScope
        ) : Package() {

            override fun toString() =
                "Package.Install(model='${model.displayName}', projectModule='${projectModule.getFullName()}', " +
                    "version='$newVersion', scope='$newScope')"
        }

        data class Remove(
            override val model: UnifiedDependency,
            override val projectModule: ProjectModule,
            val currentVersion: PackageVersion,
            val currentScope: PackageScope
        ) : Package() {

            override fun toString() =
                "Package.Remove(model='${model.displayName}', projectModule='${projectModule.getFullName()}', " +
                    "currentVersion='$currentVersion', scope='$currentScope')"
        }

        data class ChangeInstalled(
            override val model: UnifiedDependency,
            override val projectModule: ProjectModule,
            val currentVersion: PackageVersion,
            val currentScope: PackageScope,
            val newVersion: PackageVersion,
            val newScope: PackageScope
        ) : Package() {

            override fun toString() =
                "Package.ChangeInstalled(model='${model.displayName}', projectModule='${projectModule.getFullName()}', " +
                    "currentVersion='$currentVersion', currentScope='$currentScope', " +
                    "newVersion='$newVersion', newScope='$newScope')"
        }
    }

    sealed class Repository : PackageSearchOperation<UnifiedDependencyRepository>() {

        abstract override val model: UnifiedDependencyRepository

        data class Install(
            override val model: UnifiedDependencyRepository,
            override val projectModule: ProjectModule
        ) : Repository() {

            override fun toString() = "Repository.Install(model='${model.displayName}', projectModule='${projectModule.getFullName()}')"
        }

        data class Remove(
            override val model: UnifiedDependencyRepository,
            override val projectModule: ProjectModule
        ) : Repository() {

            override fun toString() = "Repository.Remove(model='${model.displayName}', projectModule='${projectModule.getFullName()}')"
        }
    }
}

==> package-search-231.8770.65-sources.jar: com/jetbrains/packagesearch/intellij/plugin/ui/toolwindow/models/operations/PackageSearchOperation.kt <==
/*******************************************************************************
 * Copyright 2000-2022 JetBrains s.r.o. and contributors.
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 * https://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 ******************************************************************************/

package com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.operations

import com.intellij.buildsystem.model.unified.UnifiedDependency
import com.intellij.buildsystem.model.unified.UnifiedDependencyRepository
import com.jetbrains.packagesearch.intellij.plugin.extensibility.PackageSearchModule
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageScope
import com.jetbrains.packagesearch.intellij.plugin.ui.toolwindow.models.PackageVersion

internal sealed class PackageSearchOperation<T> {

    abstract val model: T
    abstract val packageSearchModule: PackageSearchModule

    sealed class Package : PackageSearchOperation<UnifiedDependency>() {

        abstract override val model: UnifiedDependency

        data class Remove(
            override val model: UnifiedDependency,
            override val packageSearchModule: PackageSearchModule,
            val currentVersion: PackageVersion,
            val currentScope: PackageScope
        ) : Package() {

            override fun toString() =
                "Package.Remove(model='${model.displayName}', moduleModule='${packageSearchModule.getFullName()}', " +
                    "currentVersion='$currentVersion', scope='$currentScope')"
        }
    }

    sealed class Repository : PackageSearchOperation<UnifiedDependencyRepository>() {

        abstract override val model: UnifiedDependencyRepository

        data class Remove(
            override val model: UnifiedDependencyRepository,
            override val packageSearchModule: PackageSearchModule
        ) : Repository() {

            override fun toString() = "Repository.Remove(model='${model.displayName}', moduleModule='${packageSearchModule.getFullName()}')"
        }
    }
}
